==> upd-2.0-32.tgz: home/hadmin/html/admin/administrator.php <==
<?PHP
/* $Id: administrator.php,v 1.2 2001/03/28 08:38:09 bzizou Exp $

Editon of the administrator's parameters

This script is part of the SLIS Project initiated by the CARMI-Internet
(Acadmie de Grenoble - France 38).
Ce script fait partie du projet SLIS dmarr par le CARMI-Internet
(Acadmie de Grenoble - France 38).

This script have been writen by Bruno Bzeznik - copyright (C) 2001
Ce script  t crit par Bruno Bzeznik - copyright (C) - 2001

SLIS : Serveur de communications Linux pour l'Internet Scolaire.
Copyright (C) 1998-2001 Bruno Bzeznik

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details. You should have received a copy of the GNU General Public License
along with this program (For example ./COPYING);
if not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.

Please send all comments and bug reports by electronic mail
to: <slis@ac-grenoble.fr>
Envoyez vos suggestions et reports de bugs par e-mail  <slis@ac-grenoble.fr>
*/

// loading libs and init
require("../inc/html.inc.php");
require("../inc/lib.inc.php");
print startHTML("Admin params");
$print="1";
$users="/etc/hadmin/conf/users";

if ($action=="change") {
  if (!preg_match("/^.+\@.+\..+/",$email)) {
    print "<BR><CENTER><B><FONT SIZE=+1 COLOR=FF0000>\n";
    print $lang_Email_incorrect;
    print "</FONT></B></CENTER>\n";
  }
  else {
    $fp=fopen("$BASE/params_admin.txt","w");
    fputs($fp,$name ."\n");
    fputs($fp,$surname ."\n");
    fputs($fp,$email ."\n");
    fputs($fp,$phone ."\n");
    fclose($fp);
  }
}

if ($action=="passwd") {
  // The 2 passwd must be identical
  if ($pass1 != $pass2) {
    print "<CENTER><P><FONT COLOR=FF0000 SIZE=+1><B>\n";
    print $lang_Pass_not_changed;
    print "\n<P>$lang_2Bad_pass<BR>$lang_Try_again</B></FONT></CENTER>\n";
  }
  elseif (strlen($pass1)<6) {
    print "<CENTER><P><FONT COLOR=FF0000 SIZE=+1><B>\n";
    print $lang_Pass_not_changed;
    print "\n<P>$lang_Pass_2short<BR>$lang_Try_again</B></FONT></CENTER>\n";
  }
  elseif (strtolower($pass1)=="password") {
    print "<CENTER><P><FONT COLOR=FF0000 SIZE=+1><B>\n";
    print $lang_Pass_not_changed;
    print "\n<P>$lang_Pass_incorrect<BR>$lang_Try_again</B></FONT></CENTER>\n";
  }
  else {
    srand((double)microtime()*1000000);
    $salt=chr(rand(97,122)) . chr(rand(97,122));
    $crypted=crypt($pass1,$salt);
    exec("grep -v \"admin\" $users|egrep -v \"^\\n*\$\"> /tmp/users",$a,$r1); 
    $fp=fopen("/tmp/users",a);
    fputs($fp,"\nadmin:$crypted\n");
    fclose($fp);
    exec ("mv -f /tmp/users $users",$a,$r2);
    exec ("chmod 600 $users",$a,$r3);
    if ($r1==0 && $r2==0 && $r3==0) {
      print "<CENTER><P><B><I>$lang_Pass_changed</I></B></CENTER>";
    }
    else {
      print "<CENTER><P><FONT COLOR=FF0000 SIZE=+1><B>\n";
      print $lang_An_error_occured;
      print "\n<P>r1=$r1 r2=$r2 r3=$r3</B></FONT></CENTER>\n";
    }
  }
}

if ($print) {

// Load the file containing parameters
$params=file("$BASE/params_admin.txt");

// Prepare the form
$text = "<FONT FACE=Helvetica,Arial>\n";
$text .= "<FORM ACTION=./administrator.php?action=change METHOD=post>\n";
$text .= "<TABLE ALIGN=CENTER>\n";
$text .= "<TR><TD>$lang_Name</TD><TD><INPUT TYPE=text SIZE=40 NAME=name VALUE=\"";
$text .= $params[0] ."\"></TD></TR>\n";
$text .= "<TR><TD>$lang_Surename</TD><TD><INPUT TYPE=text SIZE=40 NAME=surname VALUE=\"";
$text .= $params[1] ."\"></TD></TR>\n";
$text .= "<TR><TD>E-mail</TD><TD><INPUT TYPE=text SIZE=40 NAME=email VALUE=\"";
$text .= $params[2] ."\"></TD></TR>\n";
$text .= "<TR><TD>$lang_Phone</TD><TD><INPUT TYPE=text SIZE=40 NAME=phone VALUE=\"";
$text .= $params[3] ."\"></TD></TR>\n";
$text .= "<TR><TD COLSPAN=2 ALIGN=CENTER><INPUT TYPE=submit VALUE=\"";
$text .= "OK\"></TD></TR>\n";
$text .= "</TABLE></FORM><HR>\n";
$text .= "<FORM ACTION=./administrator.php?action=passwd METHOD=post>\n";
//$text .= "<FORM ACTION=/cgi-bin/password.cgi METHOD=post>\n";
$text .= "<TABLE ALIGN=CENTER>\n";
$text .= "<TR><TD>$lang_Password</TD><TD><INPUT TYPE=password VALUE=\"\" NAME=pass1 SIZE=10 MAXLENGTH=8></TD></TR>";
$text .= "<TR><TD>$lang_Password_confirm</TD><TD><INPUT TYPE=password VALUE=\"\" NAME=pass2 SIZE=10 MAXLENGTH=8></TD></TR>";
$text .= "<TR><TD COLSPAN=2 ALIGN=CENTER><INPUT TYPE=submit VALUE=\"$lang_To_modif\"></TD></TR>";
$text .= "</TABLE></FORM></FONT><P>";

// print the form
$val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$text,$border,$lang_adv_Admin_params,$titre_color);
$val = center($val);
$val = saut(2)."$val";
print "$val\n";      
}

// The end
print endHTML();

?>

==> upd-3.0-75.tgz: home/hadmin/html/admin/administrator.php <==
<?PHP
/* $Id: administrator.php,v 3.2 2003/12/10 13:30:03 bzizou Exp $

Editon of the administrator's parameters

This script is part of the SLIS Project initiated by the CARMI-Internet
(Acadmie de Grenoble - France 38).
Ce script fait partie du projet SLIS dmarr par le CARMI-Internet
(Acadmie de Grenoble - France 38).

This script have been writen by Bruno Bzeznik - copyright (C) 2001
Ce script  t crit par Bruno Bzeznik - copyright (C) - 2001

SLIS : Serveur de communications Linux pour l'Internet Scolaire.
Copyright (C) 1998-2001 Bruno Bzeznik

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details. You should have received a copy of the GNU General Public License
along with this program (For example ./COPYING);
if not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.

Please send all comments and bug reports by electronic mail
to: <slis@ac-grenoble.fr>
Envoyez vos suggestions et reports de bugs par e-mail  <slis@ac-grenoble.fr>
*/

// loading libs and init
require("../inc/html.inc.php");
require("../inc/lib.inc.php");
print startHTML("Admin params");
$print="1";
$users="/etc/hadmin/conf/users";

if ($action=="change") {
  if (!preg_match("/^.+\@.+\..+/",$email)) {
    print "<BR><CENTER><B><FONT SIZE=+1 COLOR=FF0000>\n";
    print $lang_Email_incorrect;
    print "</FONT></B></CENTER>\n";
  }
  else {
    $fp=fopen("$BASE/params_admin.txt","w");
    fputs($fp,$name ."\n");
    fputs($fp,$surname ."\n");
    fputs($fp,$email ."\n");
    fputs($fp,$phone ."\n");
    fclose($fp);
    print "<BR><CENTER><B><FONT SIZE=+1 COLOR=00AA00>\n";
    print $lang_Validated;
    print "</FONT></B></CENTER>\n";
  }
}

if ($action=="passwd") {
  // The 2 passwd must be identical
  if ($pass1 != $pass2) {
    print "<CENTER><P><FONT COLOR=FF0000 SIZE=+1><B>\n";
    print $lang_Pass_not_changed;
    print "\n<P>$lang_2Bad_pass<BR>$lang_Try_again</B></FONT></CENTER>\n";
  }
  elseif (strlen($pass1)<6) {
    print "<CENTER><P><FONT COLOR=FF0000 SIZE=+1><B>\n";
    print $lang_Pass_not_changed;
    print "\n<P>$lang_Pass_2short<BR>$lang_Try_again</B></FONT></CENTER>\n";
  }
  elseif (strtolower($pass1)=="password") {
    print "<CENTER><P><FONT COLOR=FF0000 SIZE=+1><B>\n";
    print $lang_Pass_not_changed;
    print "\n<P>$lang_Pass_incorrect<BR>$lang_Try_again</B></FONT></CENTER>\n";
  }
  else {
    exec ("htpasswd -b $users admin $pass1",$a,$r1);
    if ($r1==0) {
        print "<BR><CENTER><B><FONT SIZE=+1 COLOR=00AA00>\n";
        print $lang_Pass_changed;
        print "</FONT></B></CENTER>\n";
    }
    else {
      print "<CENTER><P><FONT COLOR=FF0000 SIZE=+1><B>\n";
      print $lang_An_error_occured;
      print "\n<P>r1=$r1 a=$a</B></FONT></CENTER>\n";
    }
  }
}

if ($print) {

// Load the file containing parameters
$params=file("$BASE/params_admin.txt");

// Prepare the form
$text = "<FONT FACE=Helvetica,Arial>\n";
$text .= "<FORM ACTION=./administrator.php?action=change METHOD=post>\n";
$text .= "<TABLE ALIGN=CENTER>\n";
$text .= "<TR><TD>$lang_Name</TD><TD><INPUT TYPE=text SIZE=40 NAME=name VALUE=\"";
$text .= $params[0] ."\"></TD></TR>\n";
$text .= "<TR><TD>$lang_Surename</TD><TD><INPUT TYPE=text SIZE=40 NAME=surname VALUE=\"";
$text .= $params[1] ."\"></TD></TR>\n";
$text .= "<TR><TD>E-mail</TD><TD><INPUT TYPE=text SIZE=40 NAME=email VALUE=\"";
$text .= $params[2] ."\"></TD></TR>\n";
$text .= "<TR><TD>$lang_Phone</TD><TD><INPUT TYPE=text SIZE=40 NAME=phone VALUE=\"";
$text .= $params[3] ."\"></TD></TR>\n";
$text .= "<TR><TD COLSPAN=2 ALIGN=CENTER><INPUT TYPE=submit VALUE=\"";
$text .= "OK\"></TD></TR>\n";
$text .= "</TABLE></FORM>\n";

// print the form
$val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$text,$border,$lang_adv_Admin_params,$titre_color);
$val = center($val);
$val = saut(2)."$val";
print "$val\n";      


$text = "<FORM ACTION=./administrator.php?action=passwd METHOD=post>\n";
//$text .= "<FORM ACTION=/cgi-bin/password.cgi METHOD=post>\n";
$text .= "<TABLE ALIGN=CENTER>\n";
$text .= "<TR><TD>$lang_Password</TD><TD><INPUT TYPE=password VALUE=\"\" NAME=pass1 SIZE=10 MAXLENGTH=8></TD></TR>";
$text .= "<TR><TD>$lang_Password_confirm</TD><TD><INPUT TYPE=password VALUE=\"\" NAME=pass2 SIZE=10 MAXLENGTH=8></TD></TR>";
$text .= "<TR><TD COLSPAN=2 ALIGN=CENTER><INPUT TYPE=submit VALUE=\"$lang_To_modif\"></TD></TR>";
$text .= "</TABLE></FORM></FONT><P>";

// print the form
$val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$text,$border,$lang_adv_Admin_params,$titre_color);
$val = center($val);
$val = saut(2)."$val";
print "$val\n";      
}

// The end
print endHTML();

?>
